@@ -9,9 +9,9 @@ use Data::Sah::FilterCommon;
 use Exporter qw(import);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-01-16'; # DATE
+our $DATE = '2024-01-17'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.023'; # VERSION
+our $VERSION = '0.024'; # VERSION
 
 our @EXPORT_OK = qw(gen_filter);
 
@@ -119,7 +119,7 @@ Data::Sah::Filter - Filtering for Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.023 of Data::Sah::Filter (from Perl distribution Data-Sah-Filter), released on 2024-01-16.
+This document describes version 0.024 of Data::Sah::Filter (from Perl distribution Data-Sah-Filter), released on 2024-01-17.
 
 =head1 SYNOPSIS
 
@@ -133,6 +133,13 @@ This document describes version 0.023 of Data::Sah::Filter (from Perl distributi
  my $val = $c->("foo");        # unchanged, "foo"
  my $val = $c->(" foo ");      # "foo"
 
+Another example:
+
+ my $c = gen_filter(
+     filter_names       => [ ['Str::remove_comment' => {style=>'shell'}] ],
+     #filter_names      => ['Str::remove_comment=style,shell'], # same as above
+ );
+
 =head1 DESCRIPTION
 
 This distribution contains a standard set of filter rules for L<Data::Sah> (to
